@@ -131,6 +131,9 @@ class Events:
         resource_name = aws.get_arn(arn=target_arn).resource
         resource_type = aws.get_arn(arn=target_arn).service
 
+        account_id = aws.get_caller_identity().account_id
+        region = aws.get_region().name
+
         # If the event is being transformed, there are two variables that are required
         # `input_paths` and `input_template`
         if input_paths and input_template:
@@ -484,7 +487,7 @@ class Events:
             # Additional Logic for Lambda as a Target
             print("SQS Target --> Adding Queue Policy")
 
-            sqs_queue = aws.sqs.get_queue(name=resource_name)
+            sqs_queue_url = f"https://sqs.{region}.amazonaws.com/{account_id}/{resource_name}"
 
             # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventrule/
             rule = aws.cloudwatch.EventRule(
@@ -523,7 +526,7 @@ class Events:
             # https://www.pulumi.com/registry/packages/aws/api-docs/sqs/queuepolicy/
             aws.sqs.QueuePolicy(
                 f"{name}-queue-policy",
-                queue_url=sqs_queue.url,
+                queue_url=sqs_queue_url,
                 policy=queue_policy.json,
                 opts = pulumi.ResourceOptions(parent=rule)
             )
